@@ -1,9 +1,9 @@
-plot.ncvreg <- function(x, alpha=1, log.l=FALSE, shade=TRUE, ...)
-{
-  penalized <- which(x$penalty.factor!=0)+1
-  nonzero <- which(apply(abs(coef(x)), 1, sum)!=0)
+plot.ncvreg <- function(x, alpha=1, log.l=FALSE, shade=TRUE, ...) {
+  YY <- if (length(x$penalty.factor)==nrow(x$beta)) coef(x) else coef(x)[-1,,drop=FALSE]
+  penalized <- which(x$penalty.factor!=0)
+  nonzero <- which(apply(abs(YY), 1, sum)!=0)
   ind <- intersect(penalized, nonzero)
-  Y <- coef(x)[ind, , drop=FALSE]
+  Y <- YY[ind, , drop=FALSE]
   p <- nrow(Y)
   l <- x$lambda
   
