@@ -3,18 +3,16 @@ predict.ncvreg <- function(object, X, type=c("link", "response", "class", "coeff
   type <- match.arg(type)
   beta <- coef.ncvreg(object, lambda=lambda, which=which, drop=FALSE)
   if (type=="coefficients") return(beta)
-  if (class(object)[1]=="ncvreg") {
+  if (class(object)[1]=='ncvreg') {
     alpha <- beta[1,]
     beta <- beta[-1,,drop=FALSE]
+  } else {
+    beta <- beta
   }
 
   if (type=="nvars") return(apply(beta!=0,2,sum))
   if (type=="vars") return(drop(apply(beta!=0, 2, FUN=which)))
-  if (class(object)[1]=="ncvsurv") {
-    eta <- X %*% beta
-  } else {
-    eta <- sweep(X %*% beta, 2, alpha, "+")
-  }
+  eta <- sweep(X %*% beta, 2, alpha, "+")
   if (type=="link" || object$family=="gaussian") return(drop(eta))
   resp <- switch(object$family,
                  binomial = exp(eta)/(1+exp(eta)),
@@ -37,6 +35,6 @@ coef.ncvreg <- function(object, lambda, which=1:length(object$lambda), drop=TRUE
     beta <- (1-w)*object$beta[,l,drop=FALSE] + w*object$beta[,r,drop=FALSE]
     colnames(beta) <- round(lambda,4)
   }
-  else beta <- object$beta[,which,drop=FALSE]
+  else beta <- object$beta[, which, drop=FALSE]
   if (drop) return(drop(beta)) else return(beta)
 }
